@@ -3,7 +3,7 @@ package Net::Async::XMPP;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 1;
 
@@ -38,13 +38,13 @@ version 0.002
 		my ($client, $contact) = @_;
 		warn "Had a presence update from " . $contact->jid;
 	},
- ); 
+ );
  $loop->add($client);
  $client->login(
 	jid	=> 'user@example.com',
 	password => $ENV{NET_ASYNC_XMPP_PASSWORD},
  );
- $loop->loop_forever;
+ $loop->run;
 
 =head1 DESCRIPTION
 
@@ -54,6 +54,21 @@ See the L<Net::Async::XMPP::Client> or L<Net::Async::XMPP::Server> subclasses fo
 
 Tom Molesworth <cpan@entitymodel.com>
 
+=head1 CONTRIBUTORS
+
+With thanks to the following for contribution:
+
+=over 4
+
+=item * Arthur Axel "fREW" Schmidt for testing, documentation, pointing out some of my mistakes,
+that sort of thing
+
+=item * Paul "LeoNerd" Evans for adding L<Future>s to L<IO::Async> (and writing both in the first place)
+
+=item * Matt Trout for testing early versions
+
+=back
+
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
